#!/bin/sh
config() {
  NEW="$1"
  OLD="`dirname $NEW`/`basename $NEW .new`"
  # If there's no config file by that name, mv it over:
  if [ ! -r $OLD ]; then
    mv $NEW $OLD
  elif [ "`cat $OLD | md5sum`" = "`cat $NEW | md5sum`" ]; then # toss the redundant copy
    rm $NEW
  fi
  # Otherwise, we leave the .new copy for the admin to consider...
}

preserve_perms() {
  NEW="$1"
  OLD="$(dirname $NEW)/$(basename $NEW .new)"
  if [ -e $OLD ]; then
    cp -a $OLD ${NEW}.incoming
    cat $NEW > ${NEW}.incoming
    mv ${NEW}.incoming $NEW
  fi
  config $NEW
}

if ! grep -q "^ldap:" etc/passwd ; then
  echo "ldap:x:330:330:OpenLDAP server:/var/lib/openldap:/bin/false" >> etc/passwd
fi
if ! grep -q "^ldap:" etc/group ; then
  echo "ldap:x:330:" >> etc/group
fi
if ! grep -q "^ldap:" etc/shadow ; then
  echo "ldap:*:9797:0:::::" >> etc/shadow
fi

preserve_perms etc/rc.d/rc.openldap.new
config etc/default/slapd.new
config etc/openldap/ldap.conf.new
config etc/openldap/slapd.conf.new
config etc/openldap/slapd.ldif.new
( cd usr/bin ; rm -rf ldapadd )
( cd usr/bin ; ln -sf ldapmodify ldapadd )
( cd usr/lib ; rm -rf liblber.so )
( cd usr/lib ; ln -sf liblber.so.2.0.200 liblber.so )
( cd usr/lib ; rm -rf liblber.so.2 )
( cd usr/lib ; ln -sf liblber.so.2.0.200 liblber.so.2 )
( cd usr/lib ; rm -rf libldap.so )
( cd usr/lib ; ln -sf libldap.so.2.0.200 libldap.so )
( cd usr/lib ; rm -rf libldap.so.2 )
( cd usr/lib ; ln -sf libldap.so.2.0.200 libldap.so.2 )
( cd usr/lib ; rm -rf libslapi.so )
( cd usr/lib ; ln -sf libslapi.so.2.0.200 libslapi.so )
( cd usr/lib ; rm -rf libslapi.so.2 )
( cd usr/lib ; ln -sf libslapi.so.2.0.200 libslapi.so.2 )
( cd usr/libexec/openldap ; rm -rf accesslog.so )
( cd usr/libexec/openldap ; ln -sf accesslog.so.2.0.200 accesslog.so )
( cd usr/libexec/openldap ; rm -rf accesslog.so.2 )
( cd usr/libexec/openldap ; ln -sf accesslog.so.2.0.200 accesslog.so.2 )
( cd usr/libexec/openldap ; rm -rf argon2.so )
( cd usr/libexec/openldap ; ln -sf argon2.so.2.0.200 argon2.so )
( cd usr/libexec/openldap ; rm -rf argon2.so.2 )
( cd usr/libexec/openldap ; ln -sf argon2.so.2.0.200 argon2.so.2 )
( cd usr/libexec/openldap ; rm -rf auditlog.so )
( cd usr/libexec/openldap ; ln -sf auditlog.so.2.0.200 auditlog.so )
( cd usr/libexec/openldap ; rm -rf auditlog.so.2 )
( cd usr/libexec/openldap ; ln -sf auditlog.so.2.0.200 auditlog.so.2 )
( cd usr/libexec/openldap ; rm -rf autoca.so )
( cd usr/libexec/openldap ; ln -sf autoca.so.2.0.200 autoca.so )
( cd usr/libexec/openldap ; rm -rf autoca.so.2 )
( cd usr/libexec/openldap ; ln -sf autoca.so.2.0.200 autoca.so.2 )
( cd usr/libexec/openldap ; rm -rf back_asyncmeta.so )
( cd usr/libexec/openldap ; ln -sf back_asyncmeta.so.2.0.200 back_asyncmeta.so )
( cd usr/libexec/openldap ; rm -rf back_asyncmeta.so.2 )
( cd usr/libexec/openldap ; ln -sf back_asyncmeta.so.2.0.200 back_asyncmeta.so.2 )
( cd usr/libexec/openldap ; rm -rf back_dnssrv.so )
( cd usr/libexec/openldap ; ln -sf back_dnssrv.so.2.0.200 back_dnssrv.so )
( cd usr/libexec/openldap ; rm -rf back_dnssrv.so.2 )
( cd usr/libexec/openldap ; ln -sf back_dnssrv.so.2.0.200 back_dnssrv.so.2 )
( cd usr/libexec/openldap ; rm -rf back_ldap.so )
( cd usr/libexec/openldap ; ln -sf back_ldap.so.2.0.200 back_ldap.so )
( cd usr/libexec/openldap ; rm -rf back_ldap.so.2 )
( cd usr/libexec/openldap ; ln -sf back_ldap.so.2.0.200 back_ldap.so.2 )
( cd usr/libexec/openldap ; rm -rf back_meta.so )
( cd usr/libexec/openldap ; ln -sf back_meta.so.2.0.200 back_meta.so )
( cd usr/libexec/openldap ; rm -rf back_meta.so.2 )
( cd usr/libexec/openldap ; ln -sf back_meta.so.2.0.200 back_meta.so.2 )
( cd usr/libexec/openldap ; rm -rf back_null.so )
( cd usr/libexec/openldap ; ln -sf back_null.so.2.0.200 back_null.so )
( cd usr/libexec/openldap ; rm -rf back_null.so.2 )
( cd usr/libexec/openldap ; ln -sf back_null.so.2.0.200 back_null.so.2 )
( cd usr/libexec/openldap ; rm -rf back_passwd.so )
( cd usr/libexec/openldap ; ln -sf back_passwd.so.2.0.200 back_passwd.so )
( cd usr/libexec/openldap ; rm -rf back_passwd.so.2 )
( cd usr/libexec/openldap ; ln -sf back_passwd.so.2.0.200 back_passwd.so.2 )
( cd usr/libexec/openldap ; rm -rf back_relay.so )
( cd usr/libexec/openldap ; ln -sf back_relay.so.2.0.200 back_relay.so )
( cd usr/libexec/openldap ; rm -rf back_relay.so.2 )
( cd usr/libexec/openldap ; ln -sf back_relay.so.2.0.200 back_relay.so.2 )
( cd usr/libexec/openldap ; rm -rf back_sock.so )
( cd usr/libexec/openldap ; ln -sf back_sock.so.2.0.200 back_sock.so )
( cd usr/libexec/openldap ; rm -rf back_sock.so.2 )
( cd usr/libexec/openldap ; ln -sf back_sock.so.2.0.200 back_sock.so.2 )
( cd usr/libexec/openldap ; rm -rf back_sql.so )
( cd usr/libexec/openldap ; ln -sf back_sql.so.2.0.200 back_sql.so )
( cd usr/libexec/openldap ; rm -rf back_sql.so.2 )
( cd usr/libexec/openldap ; ln -sf back_sql.so.2.0.200 back_sql.so.2 )
( cd usr/libexec/openldap ; rm -rf collect.so )
( cd usr/libexec/openldap ; ln -sf collect.so.2.0.200 collect.so )
( cd usr/libexec/openldap ; rm -rf collect.so.2 )
( cd usr/libexec/openldap ; ln -sf collect.so.2.0.200 collect.so.2 )
( cd usr/libexec/openldap ; rm -rf constraint.so )
( cd usr/libexec/openldap ; ln -sf constraint.so.2.0.200 constraint.so )
( cd usr/libexec/openldap ; rm -rf constraint.so.2 )
( cd usr/libexec/openldap ; ln -sf constraint.so.2.0.200 constraint.so.2 )
( cd usr/libexec/openldap ; rm -rf dds.so )
( cd usr/libexec/openldap ; ln -sf dds.so.2.0.200 dds.so )
( cd usr/libexec/openldap ; rm -rf dds.so.2 )
( cd usr/libexec/openldap ; ln -sf dds.so.2.0.200 dds.so.2 )
( cd usr/libexec/openldap ; rm -rf deref.so )
( cd usr/libexec/openldap ; ln -sf deref.so.2.0.200 deref.so )
( cd usr/libexec/openldap ; rm -rf deref.so.2 )
( cd usr/libexec/openldap ; ln -sf deref.so.2.0.200 deref.so.2 )
( cd usr/libexec/openldap ; rm -rf dyngroup.so )
( cd usr/libexec/openldap ; ln -sf dyngroup.so.2.0.200 dyngroup.so )
( cd usr/libexec/openldap ; rm -rf dyngroup.so.2 )
( cd usr/libexec/openldap ; ln -sf dyngroup.so.2.0.200 dyngroup.so.2 )
( cd usr/libexec/openldap ; rm -rf dynlist.so )
( cd usr/libexec/openldap ; ln -sf dynlist.so.2.0.200 dynlist.so )
( cd usr/libexec/openldap ; rm -rf dynlist.so.2 )
( cd usr/libexec/openldap ; ln -sf dynlist.so.2.0.200 dynlist.so.2 )
( cd usr/libexec/openldap ; rm -rf homedir.so )
( cd usr/libexec/openldap ; ln -sf homedir.so.2.0.200 homedir.so )
( cd usr/libexec/openldap ; rm -rf homedir.so.2 )
( cd usr/libexec/openldap ; ln -sf homedir.so.2.0.200 homedir.so.2 )
( cd usr/libexec/openldap ; rm -rf memberof.so )
( cd usr/libexec/openldap ; ln -sf memberof.so.2.0.200 memberof.so )
( cd usr/libexec/openldap ; rm -rf memberof.so.2 )
( cd usr/libexec/openldap ; ln -sf memberof.so.2.0.200 memberof.so.2 )
( cd usr/libexec/openldap ; rm -rf nestgroup.so )
( cd usr/libexec/openldap ; ln -sf nestgroup.so.2.0.200 nestgroup.so )
( cd usr/libexec/openldap ; rm -rf nestgroup.so.2 )
( cd usr/libexec/openldap ; ln -sf nestgroup.so.2.0.200 nestgroup.so.2 )
( cd usr/libexec/openldap ; rm -rf otp.so )
( cd usr/libexec/openldap ; ln -sf otp.so.2.0.200 otp.so )
( cd usr/libexec/openldap ; rm -rf otp.so.2 )
( cd usr/libexec/openldap ; ln -sf otp.so.2.0.200 otp.so.2 )
( cd usr/libexec/openldap ; rm -rf pcache.so )
( cd usr/libexec/openldap ; ln -sf pcache.so.2.0.200 pcache.so )
( cd usr/libexec/openldap ; rm -rf pcache.so.2 )
( cd usr/libexec/openldap ; ln -sf pcache.so.2.0.200 pcache.so.2 )
( cd usr/libexec/openldap ; rm -rf ppolicy.so )
( cd usr/libexec/openldap ; ln -sf ppolicy.so.2.0.200 ppolicy.so )
( cd usr/libexec/openldap ; rm -rf ppolicy.so.2 )
( cd usr/libexec/openldap ; ln -sf ppolicy.so.2.0.200 ppolicy.so.2 )
( cd usr/libexec/openldap ; rm -rf refint.so )
( cd usr/libexec/openldap ; ln -sf refint.so.2.0.200 refint.so )
( cd usr/libexec/openldap ; rm -rf refint.so.2 )
( cd usr/libexec/openldap ; ln -sf refint.so.2.0.200 refint.so.2 )
( cd usr/libexec/openldap ; rm -rf remoteauth.so )
( cd usr/libexec/openldap ; ln -sf remoteauth.so.2.0.200 remoteauth.so )
( cd usr/libexec/openldap ; rm -rf remoteauth.so.2 )
( cd usr/libexec/openldap ; ln -sf remoteauth.so.2.0.200 remoteauth.so.2 )
( cd usr/libexec/openldap ; rm -rf retcode.so )
( cd usr/libexec/openldap ; ln -sf retcode.so.2.0.200 retcode.so )
( cd usr/libexec/openldap ; rm -rf retcode.so.2 )
( cd usr/libexec/openldap ; ln -sf retcode.so.2.0.200 retcode.so.2 )
( cd usr/libexec/openldap ; rm -rf rwm.so )
( cd usr/libexec/openldap ; ln -sf rwm.so.2.0.200 rwm.so )
( cd usr/libexec/openldap ; rm -rf rwm.so.2 )
( cd usr/libexec/openldap ; ln -sf rwm.so.2.0.200 rwm.so.2 )
( cd usr/libexec/openldap ; rm -rf seqmod.so )
( cd usr/libexec/openldap ; ln -sf seqmod.so.2.0.200 seqmod.so )
( cd usr/libexec/openldap ; rm -rf seqmod.so.2 )
( cd usr/libexec/openldap ; ln -sf seqmod.so.2.0.200 seqmod.so.2 )
( cd usr/libexec/openldap ; rm -rf sssvlv.so )
( cd usr/libexec/openldap ; ln -sf sssvlv.so.2.0.200 sssvlv.so )
( cd usr/libexec/openldap ; rm -rf sssvlv.so.2 )
( cd usr/libexec/openldap ; ln -sf sssvlv.so.2.0.200 sssvlv.so.2 )
( cd usr/libexec/openldap ; rm -rf syncprov.so )
( cd usr/libexec/openldap ; ln -sf syncprov.so.2.0.200 syncprov.so )
( cd usr/libexec/openldap ; rm -rf syncprov.so.2 )
( cd usr/libexec/openldap ; ln -sf syncprov.so.2.0.200 syncprov.so.2 )
( cd usr/libexec/openldap ; rm -rf translucent.so )
( cd usr/libexec/openldap ; ln -sf translucent.so.2.0.200 translucent.so )
( cd usr/libexec/openldap ; rm -rf translucent.so.2 )
( cd usr/libexec/openldap ; ln -sf translucent.so.2.0.200 translucent.so.2 )
( cd usr/libexec/openldap ; rm -rf unique.so )
( cd usr/libexec/openldap ; ln -sf unique.so.2.0.200 unique.so )
( cd usr/libexec/openldap ; rm -rf unique.so.2 )
( cd usr/libexec/openldap ; ln -sf unique.so.2.0.200 unique.so.2 )
( cd usr/libexec/openldap ; rm -rf valsort.so )
( cd usr/libexec/openldap ; ln -sf valsort.so.2.0.200 valsort.so )
( cd usr/libexec/openldap ; rm -rf valsort.so.2 )
( cd usr/libexec/openldap ; ln -sf valsort.so.2.0.200 valsort.so.2 )
( cd usr/man/man1 ; rm -rf ldapadd.1.gz )
( cd usr/man/man1 ; ln -sf ldapmodify.1.gz ldapadd.1.gz )
( cd usr/man/man3 ; rm -rf ber_alloc_t.3.gz )
( cd usr/man/man3 ; ln -sf lber-encode.3.gz ber_alloc_t.3.gz )
( cd usr/man/man3 ; rm -rf ber_bvarray_add.3.gz )
( cd usr/man/man3 ; ln -sf lber-types.3.gz ber_bvarray_add.3.gz )
( cd usr/man/man3 ; rm -rf ber_bvarray_free.3.gz )
( cd usr/man/man3 ; ln -sf lber-types.3.gz ber_bvarray_free.3.gz )
( cd usr/man/man3 ; rm -rf ber_bvdup.3.gz )
( cd usr/man/man3 ; ln -sf lber-types.3.gz ber_bvdup.3.gz )
( cd usr/man/man3 ; rm -rf ber_bvecadd.3.gz )
( cd usr/man/man3 ; ln -sf lber-types.3.gz ber_bvecadd.3.gz )
( cd usr/man/man3 ; rm -rf ber_bvecfree.3.gz )
( cd usr/man/man3 ; ln -sf lber-types.3.gz ber_bvecfree.3.gz )
( cd usr/man/man3 ; rm -rf ber_bvfree.3.gz )
( cd usr/man/man3 ; ln -sf lber-types.3.gz ber_bvfree.3.gz )
( cd usr/man/man3 ; rm -rf ber_bvstr.3.gz )
( cd usr/man/man3 ; ln -sf lber-types.3.gz ber_bvstr.3.gz )
( cd usr/man/man3 ; rm -rf ber_bvstrdup.3.gz )
( cd usr/man/man3 ; ln -sf lber-types.3.gz ber_bvstrdup.3.gz )
( cd usr/man/man3 ; rm -rf ber_dupbv.3.gz )
( cd usr/man/man3 ; ln -sf lber-types.3.gz ber_dupbv.3.gz )
( cd usr/man/man3 ; rm -rf ber_first_element.3.gz )
( cd usr/man/man3 ; ln -sf lber-decode.3.gz ber_first_element.3.gz )
( cd usr/man/man3 ; rm -rf ber_flush.3.gz )
( cd usr/man/man3 ; ln -sf lber-encode.3.gz ber_flush.3.gz )
( cd usr/man/man3 ; rm -rf ber_free.3.gz )
( cd usr/man/man3 ; ln -sf lber-types.3.gz ber_free.3.gz )
( cd usr/man/man3 ; rm -rf ber_get_bitstring.3.gz )
( cd usr/man/man3 ; ln -sf lber-decode.3.gz ber_get_bitstring.3.gz )
( cd usr/man/man3 ; rm -rf ber_get_boolean.3.gz )
( cd usr/man/man3 ; ln -sf lber-decode.3.gz ber_get_boolean.3.gz )
( cd usr/man/man3 ; rm -rf ber_get_enum.3.gz )
( cd usr/man/man3 ; ln -sf lber-decode.3.gz ber_get_enum.3.gz )
( cd usr/man/man3 ; rm -rf ber_get_int.3.gz )
( cd usr/man/man3 ; ln -sf lber-decode.3.gz ber_get_int.3.gz )
( cd usr/man/man3 ; rm -rf ber_get_next.3.gz )
( cd usr/man/man3 ; ln -sf lber-decode.3.gz ber_get_next.3.gz )
( cd usr/man/man3 ; rm -rf ber_get_null.3.gz )
( cd usr/man/man3 ; ln -sf lber-decode.3.gz ber_get_null.3.gz )
( cd usr/man/man3 ; rm -rf ber_get_stringa.3.gz )
( cd usr/man/man3 ; ln -sf lber-decode.3.gz ber_get_stringa.3.gz )
( cd usr/man/man3 ; rm -rf ber_get_stringb.3.gz )
( cd usr/man/man3 ; ln -sf lber-decode.3.gz ber_get_stringb.3.gz )
( cd usr/man/man3 ; rm -rf ber_next_element.3.gz )
( cd usr/man/man3 ; ln -sf lber-decode.3.gz ber_next_element.3.gz )
( cd usr/man/man3 ; rm -rf ber_peek_tag.3.gz )
( cd usr/man/man3 ; ln -sf lber-decode.3.gz ber_peek_tag.3.gz )
( cd usr/man/man3 ; rm -rf ber_printf.3.gz )
( cd usr/man/man3 ; ln -sf lber-encode.3.gz ber_printf.3.gz )
( cd usr/man/man3 ; rm -rf ber_put_enum.3.gz )
( cd usr/man/man3 ; ln -sf lber-encode.3.gz ber_put_enum.3.gz )
( cd usr/man/man3 ; rm -rf ber_put_int.3.gz )
( cd usr/man/man3 ; ln -sf lber-encode.3.gz ber_put_int.3.gz )
( cd usr/man/man3 ; rm -rf ber_put_null.3.gz )
( cd usr/man/man3 ; ln -sf lber-encode.3.gz ber_put_null.3.gz )
( cd usr/man/man3 ; rm -rf ber_put_ostring.3.gz )
( cd usr/man/man3 ; ln -sf lber-encode.3.gz ber_put_ostring.3.gz )
( cd usr/man/man3 ; rm -rf ber_put_seq.3.gz )
( cd usr/man/man3 ; ln -sf lber-encode.3.gz ber_put_seq.3.gz )
( cd usr/man/man3 ; rm -rf ber_put_set.3.gz )
( cd usr/man/man3 ; ln -sf lber-encode.3.gz ber_put_set.3.gz )
( cd usr/man/man3 ; rm -rf ber_put_string.3.gz )
( cd usr/man/man3 ; ln -sf lber-encode.3.gz ber_put_string.3.gz )
( cd usr/man/man3 ; rm -rf ber_scanf.3.gz )
( cd usr/man/man3 ; ln -sf lber-decode.3.gz ber_scanf.3.gz )
( cd usr/man/man3 ; rm -rf ber_skip_tag.3.gz )
( cd usr/man/man3 ; ln -sf lber-decode.3.gz ber_skip_tag.3.gz )
( cd usr/man/man3 ; rm -rf ber_start_set.3.gz )
( cd usr/man/man3 ; ln -sf lber-encode.3.gz ber_start_set.3.gz )
( cd usr/man/man3 ; rm -rf ber_str2bv.3.gz )
( cd usr/man/man3 ; ln -sf lber-types.3.gz ber_str2bv.3.gz )
( cd usr/man/man3 ; rm -rf ld_errno.3.gz )
( cd usr/man/man3 ; ln -sf ldap_error.3.gz ld_errno.3.gz )
( cd usr/man/man3 ; rm -rf ldap_abandon_ext.3.gz )
( cd usr/man/man3 ; ln -sf ldap_abandon.3.gz ldap_abandon_ext.3.gz )
( cd usr/man/man3 ; rm -rf ldap_add_ext.3.gz )
( cd usr/man/man3 ; ln -sf ldap_add.3.gz ldap_add_ext.3.gz )
( cd usr/man/man3 ; rm -rf ldap_add_ext_s.3.gz )
( cd usr/man/man3 ; ln -sf ldap_add.3.gz ldap_add_ext_s.3.gz )
( cd usr/man/man3 ; rm -rf ldap_add_s.3.gz )
( cd usr/man/man3 ; ln -sf ldap_add.3.gz ldap_add_s.3.gz )
( cd usr/man/man3 ; rm -rf ldap_attributetype2name.3.gz )
( cd usr/man/man3 ; ln -sf ldap_schema.3.gz ldap_attributetype2name.3.gz )
( cd usr/man/man3 ; rm -rf ldap_attributetype2str.3.gz )
( cd usr/man/man3 ; ln -sf ldap_schema.3.gz ldap_attributetype2str.3.gz )
( cd usr/man/man3 ; rm -rf ldap_attributetype_free.3.gz )
( cd usr/man/man3 ; ln -sf ldap_schema.3.gz ldap_attributetype_free.3.gz )
( cd usr/man/man3 ; rm -rf ldap_bind_s.3.gz )
( cd usr/man/man3 ; ln -sf ldap_bind.3.gz ldap_bind_s.3.gz )
( cd usr/man/man3 ; rm -rf ldap_compare_ext.3.gz )
( cd usr/man/man3 ; ln -sf ldap_compare.3.gz ldap_compare_ext.3.gz )
( cd usr/man/man3 ; rm -rf ldap_compare_ext_s.3.gz )
( cd usr/man/man3 ; ln -sf ldap_compare.3.gz ldap_compare_ext_s.3.gz )
( cd usr/man/man3 ; rm -rf ldap_compare_s.3.gz )
( cd usr/man/man3 ; ln -sf ldap_compare.3.gz ldap_compare_s.3.gz )
( cd usr/man/man3 ; rm -rf ldap_control_create.3.gz )
( cd usr/man/man3 ; ln -sf ldap_controls.3.gz ldap_control_create.3.gz )
( cd usr/man/man3 ; rm -rf ldap_control_dup.3.gz )
( cd usr/man/man3 ; ln -sf ldap_controls.3.gz ldap_control_dup.3.gz )
( cd usr/man/man3 ; rm -rf ldap_control_find.3.gz )
( cd usr/man/man3 ; ln -sf ldap_controls.3.gz ldap_control_find.3.gz )
( cd usr/man/man3 ; rm -rf ldap_control_free.3.gz )
( cd usr/man/man3 ; ln -sf ldap_controls.3.gz ldap_control_free.3.gz )
( cd usr/man/man3 ; rm -rf ldap_controls_dup.3.gz )
( cd usr/man/man3 ; ln -sf ldap_controls.3.gz ldap_controls_dup.3.gz )
( cd usr/man/man3 ; rm -rf ldap_controls_free.3.gz )
( cd usr/man/man3 ; ln -sf ldap_controls.3.gz ldap_controls_free.3.gz )
( cd usr/man/man3 ; rm -rf ldap_count_entries.3.gz )
( cd usr/man/man3 ; ln -sf ldap_first_entry.3.gz ldap_count_entries.3.gz )
( cd usr/man/man3 ; rm -rf ldap_count_messages.3.gz )
( cd usr/man/man3 ; ln -sf ldap_first_message.3.gz ldap_count_messages.3.gz )
( cd usr/man/man3 ; rm -rf ldap_count_references.3.gz )
( cd usr/man/man3 ; ln -sf ldap_first_reference.3.gz ldap_count_references.3.gz )
( cd usr/man/man3 ; rm -rf ldap_count_values.3.gz )
( cd usr/man/man3 ; ln -sf ldap_get_values.3.gz ldap_count_values.3.gz )
( cd usr/man/man3 ; rm -rf ldap_count_values_len.3.gz )
( cd usr/man/man3 ; ln -sf ldap_get_values.3.gz ldap_count_values_len.3.gz )
( cd usr/man/man3 ; rm -rf ldap_dcedn2dn.3.gz )
( cd usr/man/man3 ; ln -sf ldap_get_dn.3.gz ldap_dcedn2dn.3.gz )
( cd usr/man/man3 ; rm -rf ldap_delete_ext.3.gz )
( cd usr/man/man3 ; ln -sf ldap_delete.3.gz ldap_delete_ext.3.gz )
( cd usr/man/man3 ; rm -rf ldap_delete_ext_s.3.gz )
( cd usr/man/man3 ; ln -sf ldap_delete.3.gz ldap_delete_ext_s.3.gz )
( cd usr/man/man3 ; rm -rf ldap_delete_s.3.gz )
( cd usr/man/man3 ; ln -sf ldap_delete.3.gz ldap_delete_s.3.gz )
( cd usr/man/man3 ; rm -rf ldap_destroy.3.gz )
( cd usr/man/man3 ; ln -sf ldap_dup.3.gz ldap_destroy.3.gz )
( cd usr/man/man3 ; rm -rf ldap_dn2ad_canonical.3.gz )
( cd usr/man/man3 ; ln -sf ldap_get_dn.3.gz ldap_dn2ad_canonical.3.gz )
( cd usr/man/man3 ; rm -rf ldap_dn2dcedn.3.gz )
( cd usr/man/man3 ; ln -sf ldap_get_dn.3.gz ldap_dn2dcedn.3.gz )
( cd usr/man/man3 ; rm -rf ldap_dn2str.3.gz )
( cd usr/man/man3 ; ln -sf ldap_get_dn.3.gz ldap_dn2str.3.gz )
( cd usr/man/man3 ; rm -rf ldap_dn2ufn.3.gz )
( cd usr/man/man3 ; ln -sf ldap_get_dn.3.gz ldap_dn2ufn.3.gz )
( cd usr/man/man3 ; rm -rf ldap_dnfree.3.gz )
( cd usr/man/man3 ; ln -sf ldap_get_dn.3.gz ldap_dnfree.3.gz )
( cd usr/man/man3 ; rm -rf ldap_err2string.3.gz )
( cd usr/man/man3 ; ln -sf ldap_error.3.gz ldap_err2string.3.gz )
( cd usr/man/man3 ; rm -rf ldap_errlist.3.gz )
( cd usr/man/man3 ; ln -sf ldap_error.3.gz ldap_errlist.3.gz )
( cd usr/man/man3 ; rm -rf ldap_explode_dn.3.gz )
( cd usr/man/man3 ; ln -sf ldap_get_dn.3.gz ldap_explode_dn.3.gz )
( cd usr/man/man3 ; rm -rf ldap_explode_rdn.3.gz )
( cd usr/man/man3 ; ln -sf ldap_get_dn.3.gz ldap_explode_rdn.3.gz )
( cd usr/man/man3 ; rm -rf ldap_extended_operation_s.3.gz )
( cd usr/man/man3 ; ln -sf ldap_extended_operation.3.gz ldap_extended_operation_s.3.gz )
( cd usr/man/man3 ; rm -rf ldap_free_urldesc.3.gz )
( cd usr/man/man3 ; ln -sf ldap_url.3.gz ldap_free_urldesc.3.gz )
( cd usr/man/man3 ; rm -rf ldap_get_attribute_ber.3.gz )
( cd usr/man/man3 ; ln -sf ldap_first_attribute.3.gz ldap_get_attribute_ber.3.gz )
( cd usr/man/man3 ; rm -rf ldap_get_values_len.3.gz )
( cd usr/man/man3 ; ln -sf ldap_get_values.3.gz ldap_get_values_len.3.gz )
( cd usr/man/man3 ; rm -rf ldap_init.3.gz )
( cd usr/man/man3 ; ln -sf ldap_open.3.gz ldap_init.3.gz )
( cd usr/man/man3 ; rm -rf ldap_init_fd.3.gz )
( cd usr/man/man3 ; ln -sf ldap_open.3.gz ldap_init_fd.3.gz )
( cd usr/man/man3 ; rm -rf ldap_initialize.3.gz )
( cd usr/man/man3 ; ln -sf ldap_open.3.gz ldap_initialize.3.gz )
( cd usr/man/man3 ; rm -rf ldap_install_tls.3.gz )
( cd usr/man/man3 ; ln -sf ldap_tls.3.gz ldap_install_tls.3.gz )
( cd usr/man/man3 ; rm -rf ldap_is_ldap_url.3.gz )
( cd usr/man/man3 ; ln -sf ldap_url.3.gz ldap_is_ldap_url.3.gz )
( cd usr/man/man3 ; rm -rf ldap_matchingrule2name.3.gz )
( cd usr/man/man3 ; ln -sf ldap_schema.3.gz ldap_matchingrule2name.3.gz )
( cd usr/man/man3 ; rm -rf ldap_matchingrule2str.3.gz )
( cd usr/man/man3 ; ln -sf ldap_schema.3.gz ldap_matchingrule2str.3.gz )
( cd usr/man/man3 ; rm -rf ldap_matchingrule_free.3.gz )
( cd usr/man/man3 ; ln -sf ldap_schema.3.gz ldap_matchingrule_free.3.gz )
( cd usr/man/man3 ; rm -rf ldap_memalloc.3.gz )
( cd usr/man/man3 ; ln -sf ldap_memory.3.gz ldap_memalloc.3.gz )
( cd usr/man/man3 ; rm -rf ldap_memcalloc.3.gz )
( cd usr/man/man3 ; ln -sf ldap_memory.3.gz ldap_memcalloc.3.gz )
( cd usr/man/man3 ; rm -rf ldap_memfree.3.gz )
( cd usr/man/man3 ; ln -sf ldap_memory.3.gz ldap_memfree.3.gz )
( cd usr/man/man3 ; rm -rf ldap_memrealloc.3.gz )
( cd usr/man/man3 ; ln -sf ldap_memory.3.gz ldap_memrealloc.3.gz )
( cd usr/man/man3 ; rm -rf ldap_memvfree.3.gz )
( cd usr/man/man3 ; ln -sf ldap_memory.3.gz ldap_memvfree.3.gz )
( cd usr/man/man3 ; rm -rf ldap_modify_ext.3.gz )
( cd usr/man/man3 ; ln -sf ldap_modify.3.gz ldap_modify_ext.3.gz )
( cd usr/man/man3 ; rm -rf ldap_modify_ext_s.3.gz )
( cd usr/man/man3 ; ln -sf ldap_modify.3.gz ldap_modify_ext_s.3.gz )
( cd usr/man/man3 ; rm -rf ldap_modify_s.3.gz )
( cd usr/man/man3 ; ln -sf ldap_modify.3.gz ldap_modify_s.3.gz )
( cd usr/man/man3 ; rm -rf ldap_modrdn2.3.gz )
( cd usr/man/man3 ; ln -sf ldap_modrdn.3.gz ldap_modrdn2.3.gz )
( cd usr/man/man3 ; rm -rf ldap_modrdn2_s.3.gz )
( cd usr/man/man3 ; ln -sf ldap_modrdn.3.gz ldap_modrdn2_s.3.gz )
( cd usr/man/man3 ; rm -rf ldap_modrdn_s.3.gz )
( cd usr/man/man3 ; ln -sf ldap_modrdn.3.gz ldap_modrdn_s.3.gz )
( cd usr/man/man3 ; rm -rf ldap_mods_free.3.gz )
( cd usr/man/man3 ; ln -sf ldap_modify.3.gz ldap_mods_free.3.gz )
( cd usr/man/man3 ; rm -rf ldap_msgfree.3.gz )
( cd usr/man/man3 ; ln -sf ldap_result.3.gz ldap_msgfree.3.gz )
( cd usr/man/man3 ; rm -rf ldap_msgid.3.gz )
( cd usr/man/man3 ; ln -sf ldap_result.3.gz ldap_msgid.3.gz )
( cd usr/man/man3 ; rm -rf ldap_msgtype.3.gz )
( cd usr/man/man3 ; ln -sf ldap_result.3.gz ldap_msgtype.3.gz )
( cd usr/man/man3 ; rm -rf ldap_next_attribute.3.gz )
( cd usr/man/man3 ; ln -sf ldap_first_attribute.3.gz ldap_next_attribute.3.gz )
( cd usr/man/man3 ; rm -rf ldap_next_entry.3.gz )
( cd usr/man/man3 ; ln -sf ldap_first_entry.3.gz ldap_next_entry.3.gz )
( cd usr/man/man3 ; rm -rf ldap_next_message.3.gz )
( cd usr/man/man3 ; ln -sf ldap_first_message.3.gz ldap_next_message.3.gz )
( cd usr/man/man3 ; rm -rf ldap_next_reference.3.gz )
( cd usr/man/man3 ; ln -sf ldap_first_reference.3.gz ldap_next_reference.3.gz )
( cd usr/man/man3 ; rm -rf ldap_objectclass2name.3.gz )
( cd usr/man/man3 ; ln -sf ldap_schema.3.gz ldap_objectclass2name.3.gz )
( cd usr/man/man3 ; rm -rf ldap_objectclass2str.3.gz )
( cd usr/man/man3 ; ln -sf ldap_schema.3.gz ldap_objectclass2str.3.gz )
( cd usr/man/man3 ; rm -rf ldap_objectclass_free.3.gz )
( cd usr/man/man3 ; ln -sf ldap_schema.3.gz ldap_objectclass_free.3.gz )
( cd usr/man/man3 ; rm -rf ldap_parse_extended_result.3.gz )
( cd usr/man/man3 ; ln -sf ldap_parse_result.3.gz ldap_parse_extended_result.3.gz )
( cd usr/man/man3 ; rm -rf ldap_parse_intermediate.3.gz )
( cd usr/man/man3 ; ln -sf ldap_parse_result.3.gz ldap_parse_intermediate.3.gz )
( cd usr/man/man3 ; rm -rf ldap_parse_sasl_bind_result.3.gz )
( cd usr/man/man3 ; ln -sf ldap_parse_result.3.gz ldap_parse_sasl_bind_result.3.gz )
( cd usr/man/man3 ; rm -rf ldap_perror.3.gz )
( cd usr/man/man3 ; ln -sf ldap_error.3.gz ldap_perror.3.gz )
( cd usr/man/man3 ; rm -rf ldap_rename_s.3.gz )
( cd usr/man/man3 ; ln -sf ldap_rename.3.gz ldap_rename_s.3.gz )
( cd usr/man/man3 ; rm -rf ldap_result2error.3.gz )
( cd usr/man/man3 ; ln -sf ldap_error.3.gz ldap_result2error.3.gz )
( cd usr/man/man3 ; rm -rf ldap_sasl_bind.3.gz )
( cd usr/man/man3 ; ln -sf ldap_bind.3.gz ldap_sasl_bind.3.gz )
( cd usr/man/man3 ; rm -rf ldap_sasl_bind_s.3.gz )
( cd usr/man/man3 ; ln -sf ldap_bind.3.gz ldap_sasl_bind_s.3.gz )
( cd usr/man/man3 ; rm -rf ldap_scherr2str.3.gz )
( cd usr/man/man3 ; ln -sf ldap_schema.3.gz ldap_scherr2str.3.gz )
( cd usr/man/man3 ; rm -rf ldap_search_ext.3.gz )
( cd usr/man/man3 ; ln -sf ldap_search.3.gz ldap_search_ext.3.gz )
( cd usr/man/man3 ; rm -rf ldap_search_ext_s.3.gz )
( cd usr/man/man3 ; ln -sf ldap_search.3.gz ldap_search_ext_s.3.gz )
( cd usr/man/man3 ; rm -rf ldap_search_s.3.gz )
( cd usr/man/man3 ; ln -sf ldap_search.3.gz ldap_search_s.3.gz )
( cd usr/man/man3 ; rm -rf ldap_search_st.3.gz )
( cd usr/man/man3 ; ln -sf ldap_search.3.gz ldap_search_st.3.gz )
( cd usr/man/man3 ; rm -rf ldap_set_option.3.gz )
( cd usr/man/man3 ; ln -sf ldap_get_option.3.gz ldap_set_option.3.gz )
( cd usr/man/man3 ; rm -rf ldap_set_rebind_proc.3.gz )
( cd usr/man/man3 ; ln -sf ldap_bind.3.gz ldap_set_rebind_proc.3.gz )
( cd usr/man/man3 ; rm -rf ldap_set_urllist_proc.3.gz )
( cd usr/man/man3 ; ln -sf ldap_open.3.gz ldap_set_urllist_proc.3.gz )
( cd usr/man/man3 ; rm -rf ldap_simple_bind.3.gz )
( cd usr/man/man3 ; ln -sf ldap_bind.3.gz ldap_simple_bind.3.gz )
( cd usr/man/man3 ; rm -rf ldap_simple_bind_s.3.gz )
( cd usr/man/man3 ; ln -sf ldap_bind.3.gz ldap_simple_bind_s.3.gz )
( cd usr/man/man3 ; rm -rf ldap_sort_entries.3.gz )
( cd usr/man/man3 ; ln -sf ldap_sort.3.gz ldap_sort_entries.3.gz )
( cd usr/man/man3 ; rm -rf ldap_sort_strcasecmp.3.gz )
( cd usr/man/man3 ; ln -sf ldap_sort.3.gz ldap_sort_strcasecmp.3.gz )
( cd usr/man/man3 ; rm -rf ldap_sort_values.3.gz )
( cd usr/man/man3 ; ln -sf ldap_sort.3.gz ldap_sort_values.3.gz )
( cd usr/man/man3 ; rm -rf ldap_start_tls.3.gz )
( cd usr/man/man3 ; ln -sf ldap_tls.3.gz ldap_start_tls.3.gz )
( cd usr/man/man3 ; rm -rf ldap_start_tls_s.3.gz )
( cd usr/man/man3 ; ln -sf ldap_tls.3.gz ldap_start_tls_s.3.gz )
( cd usr/man/man3 ; rm -rf ldap_str2attributetype.3.gz )
( cd usr/man/man3 ; ln -sf ldap_schema.3.gz ldap_str2attributetype.3.gz )
( cd usr/man/man3 ; rm -rf ldap_str2dn.3.gz )
( cd usr/man/man3 ; ln -sf ldap_get_dn.3.gz ldap_str2dn.3.gz )
( cd usr/man/man3 ; rm -rf ldap_str2matchingrule.3.gz )
( cd usr/man/man3 ; ln -sf ldap_schema.3.gz ldap_str2matchingrule.3.gz )
( cd usr/man/man3 ; rm -rf ldap_str2objectclass.3.gz )
( cd usr/man/man3 ; ln -sf ldap_schema.3.gz ldap_str2objectclass.3.gz )
( cd usr/man/man3 ; rm -rf ldap_str2syntax.3.gz )
( cd usr/man/man3 ; ln -sf ldap_schema.3.gz ldap_str2syntax.3.gz )
( cd usr/man/man3 ; rm -rf ldap_strdup.3.gz )
( cd usr/man/man3 ; ln -sf ldap_memory.3.gz ldap_strdup.3.gz )
( cd usr/man/man3 ; rm -rf ldap_syntax2name.3.gz )
( cd usr/man/man3 ; ln -sf ldap_schema.3.gz ldap_syntax2name.3.gz )
( cd usr/man/man3 ; rm -rf ldap_syntax2str.3.gz )
( cd usr/man/man3 ; ln -sf ldap_schema.3.gz ldap_syntax2str.3.gz )
( cd usr/man/man3 ; rm -rf ldap_syntax_free.3.gz )
( cd usr/man/man3 ; ln -sf ldap_schema.3.gz ldap_syntax_free.3.gz )
( cd usr/man/man3 ; rm -rf ldap_tls_inplace.3.gz )
( cd usr/man/man3 ; ln -sf ldap_tls.3.gz ldap_tls_inplace.3.gz )
( cd usr/man/man3 ; rm -rf ldap_unbind.3.gz )
( cd usr/man/man3 ; ln -sf ldap_bind.3.gz ldap_unbind.3.gz )
( cd usr/man/man3 ; rm -rf ldap_unbind_ext.3.gz )
( cd usr/man/man3 ; ln -sf ldap_bind.3.gz ldap_unbind_ext.3.gz )
( cd usr/man/man3 ; rm -rf ldap_unbind_ext_s.3.gz )
( cd usr/man/man3 ; ln -sf ldap_bind.3.gz ldap_unbind_ext_s.3.gz )
( cd usr/man/man3 ; rm -rf ldap_unbind_s.3.gz )
( cd usr/man/man3 ; ln -sf ldap_bind.3.gz ldap_unbind_s.3.gz )
( cd usr/man/man3 ; rm -rf ldap_url_parse.3.gz )
( cd usr/man/man3 ; ln -sf ldap_url.3.gz ldap_url_parse.3.gz )
( cd usr/man/man3 ; rm -rf ldap_value_free.3.gz )
( cd usr/man/man3 ; ln -sf ldap_get_values.3.gz ldap_value_free.3.gz )
( cd usr/man/man3 ; rm -rf ldap_value_free_len.3.gz )
( cd usr/man/man3 ; ln -sf ldap_get_values.3.gz ldap_value_free_len.3.gz )
( cd usr/man/man5 ; rm -rf slapo-sock.5.gz )
( cd usr/man/man5 ; ln -sf slapd-sock.5.gz slapo-sock.5.gz )
( cd usr/sbin ; rm -rf slapacl )
( cd usr/sbin ; ln -sf ../libexec/slapd slapacl )
( cd usr/sbin ; rm -rf slapadd )
( cd usr/sbin ; ln -sf ../libexec/slapd slapadd )
( cd usr/sbin ; rm -rf slapauth )
( cd usr/sbin ; ln -sf ../libexec/slapd slapauth )
( cd usr/sbin ; rm -rf slapcat )
( cd usr/sbin ; ln -sf ../libexec/slapd slapcat )
( cd usr/sbin ; rm -rf slapd )
( cd usr/sbin ; ln -sf ../libexec/slapd slapd )
( cd usr/sbin ; rm -rf slapdn )
( cd usr/sbin ; ln -sf ../libexec/slapd slapdn )
( cd usr/sbin ; rm -rf slapindex )
( cd usr/sbin ; ln -sf ../libexec/slapd slapindex )
( cd usr/sbin ; rm -rf slapmodify )
( cd usr/sbin ; ln -sf ../libexec/slapd slapmodify )
( cd usr/sbin ; rm -rf slappasswd )
( cd usr/sbin ; ln -sf ../libexec/slapd slappasswd )
( cd usr/sbin ; rm -rf slapschema )
( cd usr/sbin ; ln -sf ../libexec/slapd slapschema )
( cd usr/sbin ; rm -rf slaptest )
( cd usr/sbin ; ln -sf ../libexec/slapd slaptest )
